*********************************************************
** .do File for Druckman, Sharrow, and Rothschild 2018 **
*********************************************************

**Setting weights
svyset [pweight=weight3]	
	
**creating men's basketball dummy

gen m_basketball = 0.
replace m_basketball = 1 if gender==0 & basketball==1

**creating running (track and/or cross) country dummy
gen running = 0
recode running 0/0 = 1 if track_field == 1 | xcountry == 1

**Correcting variable name
	
gen shdist_sportequip_b = shdist_sportsequip_b

**Create women discrimination variable 

alpha discrim_problem favors obstacles discrim_complain
gen favors2 = 6- favors
gen discrim_complain2 = 6- discrim_complain
gen obstacles2 = (4*obstacles - 1)/3
alpha discrim_problem favors2 obstacles2 discrim_complain2
egen womendiscr = rowmean(discrim_problem favors2 obstacles2 discrim_complain2)

***look at relationships between distribution measures
alpha acdist_resources_b acdist_financial_b acdist_opp_b acdist_teams_b acdist_scholar_b acdist_practice_b acdist_competition_b acdist_travel_b acdist_strengthequip_b acdist_strengthopp_b acdist_press_b acdist_media_b acdist_coaches_b acdist_numcoaches_b acdist_medical_b acdist_academic_b acdist_admin_b acdist_recruit_b acdist_locker_b acdist_pfacilities_b acdist_cfacilities_b acdist_apparel_b acdist_sportequip_b
alpha shdist_resources_b shdist_financial_b shdist_opp_b shdist_teams_b shdist_scholar_b shdist_practice_b shdist_competition_b shdist_travel_b shdist_strengthequip_b shdist_strengthopp_b shdist_press_b shdist_media_b shdist_coaches_b shdist_numcoaches_b shdist_medical_b shdist_academic_b shdist_admin_b shdist_recruit_b shdist_locker_b shdist_pfacilities_b shdist_cfacilities_b shdist_apparel_b shdist_sportequip_b


***Creating three types of scales -- opportunity, personnel, equipment.

alpha acdist_financial_b acdist_opp_b acdist_teams_b acdist_scholar_b acdist_practice_b acdist_competition_b acdist_travel_b acdist_strengthopp_b acdist_press_b acdist_media_b
alpha acdist_coaches_b acdist_numcoaches_b acdist_medical_b acdist_academic_b acdist_admin_b acdist_recruit_b
alpha acdist_locker_b acdist_pfacilities_b acdist_cfacilities_b acdist_uniform_b acdist_apparel_b acdist_sportequip_b acdist_strengthequip_b
alpha shdist_financial_b shdist_opp_b shdist_teams_b shdist_scholar_b shdist_practice_b shdist_competition_b shdist_travel_b shdist_strengthopp_b shdist_press_b shdist_media_b
alpha shdist_coaches_b shdist_numcoaches_b shdist_medical_b shdist_academic_b shdist_admin_b shdist_recruit_b
alpha shdist_locker_b shdist_pfacilities_b shdist_cfacilities_b shdist_uniform_b shdist_apparel_b shdist_sportequip_b shdist_strengthequip_b

egen opportunity = rowmean(acdist_financial_b acdist_opp_b acdist_teams_b acdist_scholar_b acdist_practice_b acdist_competition_b acdist_travel_b acdist_strengthopp_b acdist_press_b acdist_media_b)
egen shopportunity = rowmean(shdist_financial_b shdist_opp_b shdist_teams_b shdist_scholar_b shdist_practice_b shdist_competition_b shdist_travel_b shdist_strengthopp_b shdist_press_b shdist_media_b)
egen personnel = rowmean(acdist_coaches_b acdist_numcoaches_b acdist_medical_b acdist_academic_b acdist_admin_b acdist_recruit_b)
egen shpersonnel = rowmean(shdist_coaches_b shdist_numcoaches_b shdist_medical_b shdist_academic_b shdist_admin_b shdist_recruit_b)
egen equipment = rowmean(acdist_locker_b acdist_pfacilities_b acdist_cfacilities_b acdist_uniform_b acdist_apparel_b acdist_sportequip_b acdist_strengthequip_b)
egen shequipment = rowmean(shdist_locker_b shdist_pfacilities_b shdist_cfacilities_b shdist_uniform_b shdist_apparel_b shdist_sportequip_b shdist_strengthequip_b)


**Create Difference Variables

local sufflist "resources_b financial_b opp_b teams_b scholar_b practice_b competition_b travel_b strengthequip_b strengthopp_b press_b media_b coaches_b numcoaches_b medical_b academic_b admin_b recruit_b locker_b pfacilities_b cfacilities_b apparel_b uniform_b sportequip_b"
foreach z of local sufflist {
	generate diff_`z' = acdist_`z' - shdist_`z'
	}
	
** Creating difference variables by category:

alpha diff_financial_b diff_opp_b diff_teams_b diff_scholar_b diff_practice_b diff_competition_b diff_travel_b diff_strengthopp_b diff_press_b diff_media_b
alpha diff_coaches_b diff_numcoaches_b diff_medical_b diff_academic_b diff_admin_b diff_recruit_b
alpha diff_locker_b diff_pfacilities_b diff_cfacilities_b diff_uniform_b diff_apparel_b diff_sportequip_b diff_strengthequip_b

egen diff_opportunity = rowmean(diff_financial_b diff_opp_b diff_teams_b diff_scholar_b diff_practice_b diff_competition_b diff_travel_b diff_strengthopp_b diff_press_b diff_media_b)
egen diff_personnel = rowmean(diff_coaches_b diff_numcoaches_b diff_medical_b diff_academic_b diff_admin_b diff_recruit_b)
egen diff_equipment = rowmean(diff_locker_b diff_pfacilities_b diff_cfacilities_b diff_uniform_b diff_apparel_b diff_sportequip_b diff_strengthequip_b)

**Look at overall resources and then actual diss for 3 types, should distribution for three types and redistribution for three types.
svy: regress opportunity gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota
svy: regress personnel gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 
svy: regress equipment gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 
svy: regress acdist_resources_b gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota

svy: regress diff_opportunity gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota
svy: regress diff_personnel gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota
svy: regress diff_equipment gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 
svy: regress diff_resources_b gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 

** Include/exclude men's basketball and footbal
gen inclbballfb = .
recode inclbballfb ./. = 1 if includemens == 0 & includemens_strong == 3
recode inclbballfb ./. = 2 if includemens == 0 & includemens_strong == 2
recode inclbballfb ./. = 3 if includemens == 0 & includemens_strong == 1
recode inclbballfb ./. = 4 if includemens == 1 
recode inclbballfb ./. = 5 if includemens == 2 & includemens_strong == 1
recode inclbballfb ./. = 1 if includemens == 2 & includemens_strong == 2
recode inclbballfb ./. = 1 if includemens == 2 & includemens_strong == 3

** Title IX knowledge
svy: mlogit titleix_know gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 
outreg2 using KnowTitleIX, alpha(.01, .05, .1) bdec(3) sdec(3) ctitle("Knowledge") word replace

** Title IX support and action
svy: regress titleix_agree gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 

egen univexternal = rowmean(external_1_uni external_2_uni)
egen univinternal = rowmean(internal_1_uni internal_2_uni) 

alpha part_coach part_director part_teammates part_university part_petition part_protest part_otherpetition
egen schactionsequ = rowmean( part_coach part_director part_teammates part_university part_petition part_protest part_otherpetition)

svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota 


*** Predicted Means ***

* Estimating population means and standard deviations
local reglist "gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota"
foreach z of local reglist {
	svy: mean `z'
	estat sd
	}
	
* for womendiscr:

* estimating mean - 1s.d.
display 3.4904 - .7479

* estimating mean + 1s.d.
display 3.4904 + .7479

* Perceptions of advantage

estsimp regress opportunity gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

estsimp regress personnel gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

estsimp regress equipment gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

estsimp regress acdist_resources_b gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

* Redistribution

estsimp regress diff_opportunity gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

estsimp regress diff_personnel gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

estsimp regress diff_equipment gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

estsimp regress diff_resources_b gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota [pweight=weight3]
setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
simqi
setx gender 0
simqi
setx gender 1
simqi

setx gender .4495 black .0886 asian .0267 hispanic .0209 highschool .9506 year 2.4918 income 3.6699 ideology 4.1236 womendiscr 3.4904 scholarship_athletic .5333 wrestling .0555 football .1882 m_basketball .0152 running .1539 university_iowa .0791 university_minnesota .0869
setx womendiscr 2.7425
simqi
setx womendiscr 4.2383
simqi
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 b17 b18

** regressions by income
svy: regress opportunity gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income < 4
svy: regress personnel gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income < 4 
svy: regress equipment gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income < 4
svy: regress acdist_resources_b gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income < 4

svy: regress opportunity gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income > 3
svy: regress personnel gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income > 3
svy: regress equipment gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income > 3
svy: regress acdist_resources_b gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income > 3

svy: regress titleix_agree gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income < 4 
svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota if income < 4

svy: regress titleix_agree gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota if income > 3 
svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota if income > 3

** regressions by team/individual sport
gen teamsport = 0
recode teamsport 0/0 = 1 if baseball == 1 | basketball == 1 | bowling == 1 | f_hockey == 1 | football == 1 | i_hockey == 1 | lacrosse == 1 | rowing == 1 | l_rowing == 1 | soccer == 1 | softball == 1 | b_volleyball == 1 | volleyball == 1 | w_polo == 1 | s_swimming == 1

svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota if teamsport == 0 
svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota if teamsport == 1 & running == 0


***KEY TESTS of things in paper
svy: tab titleix_know
svy: tab includemens

**THESE are all main DVs used
svy: mean opportunity personnel equipment acdist_resources_b shopportunity shpersonnel shequipment shdist_resources_b diff_opportunity  diff_personnel  diff_equipment  diff_resources_b  titleix_agree schactionsequ titleix_know dist_exclude_a diffdist_exclude 
estat sd
svy: mean diff_opportunity  
estat sd
svy: mean diff_personnel  
estat sd
svy: mean diff_equipment  
estat sd
svy: mean diff_resources_b  
estat sd
svy: mean titleix_agree
estat sd
svy: tab titleix_know

***this is for the mean values and t-tests reported in the results section (and footnotes).
svy: mean opportunity 
estat sd
svy: mean personnel 
estat sd
svy: mean equipment 
estat sd
svy: mean acdist_resources_b 
estat sd
svy: mean shopportunity 
estat sd
svy: mean shpersonnel 
estat sd
svy: mean shequipment 
estat sd
svy: mean shdist_resources_b 
estat sd


svy: mean shopportunity if gender == 0 
estat sd
svy: mean shpersonnel if gender == 0
estat sd
svy: mean shequipment if gender == 0 
estat sd
svy: mean shdist_resources_b  if gender == 0
estat sd

svy: mean shopportunity  if gender == 1
estat sd
svy: mean shpersonnel  if gender == 1
estat sd
svy: mean shequipment  if gender == 1
estat sd
svy: mean shdist_resources_b  if gender == 1
estat sd

svy: tab shopportunity 
svy: tab shpersonnel 
svy: tab shequipment 
svy: tab shdist_resources_b 

svy: mean dist_exclude_a

**resources 
ttesti 1342 3.31 .79 1287 3.09 .41
**equipment
ttesti 1347 3.20 .56 1289 3.06 .33
**personnel
ttesti 1328 3.21 .48 1281 3.03 .33
**equpiment
ttesti 1341 3.30 .59 1288 3.04 .34

**mediation
egen overalineq = rowmean(opportunity personnel equipment acdist_resources_b)
svy: regress titleix_agree gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota 
svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota 
svy: regress titleix_agree gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running university_iowa university_minnesota overalineq
svy: regress schactionsequ gender black asian hispanic highschool year income ideology womendiscr scholarship_athletic wrestling football m_basketball running univexternal univinternal trust_uni university_iowa university_minnesota overalineq 


** Sample demographics

svy: tab gender
svy: tab white
svy: tab black
svy: tab asian
svy: tab hispanic
svy: tab year
svy: tab scholarship_athletic 
svy: tab  highschool
svy: mean income
svy: mean womendiscr 
svy: mean ideology
svy: tab baseball
svy: tab basketball
svy: tab b_volleyball
svy: tab diving
svy: tab fencing
svy: tab f_hockey
svy: tab football
svy: tab golf
svy: tab gymnastics 
svy: tab i_hockey
svy: tab lacrosse
svy: tab l_rowing
svy: tab pistol
svy: tab rifle
svy: tab rowing
svy: tab soccer
svy: tab softball
svy: tab swimming
svy: tab s_swimming 
svy: tab tennis
svy: tab track_field
svy: tab volleyball 
svy: tab w_polo
svy: tab wrestling

svy: tab university_illinois 
svy: tab university_indiana 
svy: tab university_iowa 
svy: tab university_michigan 
svy: tab university_mstate 
svy: tab university_minnesota 
svy: tab university_northwestern 
svy: tab university_ostate 
svy: tab university_pstate 
svy: tab university_purdue 
svy: tab university_rutgers
svy: tab university_wisconsin

svy: tab titleix_heard
